.. _about:

About Plopp
===========

Development
-----------

Plopp is an open source project by the `European Spallation Source ERIC <https://europeanspallationsource.se/>`_ (ESS).

License
-------

Plopp is available as open source under the `BSD-3 license <https://opensource.org/licenses/BSD-3-Clause>`_.

Citing Plopp
------------

Please cite the following:

.. image:: https://zenodo.org/badge/528859752.svg
   :target: https://zenodo.org/badge/latestdoi/528859752

To cite a specific version of Plopp, select the desired version on Zenodo to get the corresponding DOI.

Source code and development
---------------------------

Plopp is hosted and developed `on GitHub <https://github.com/scipp/plopp>`_.

Contributing to Plopp
---------------------

Contributions, bug reports, and ideas are always welcome.
If in doubt whether a feature falls within the scope of Plopp please `ask on GitHub <https://github.com/scipp/plopp/issues>`_ before implementing functionality, to reduce the risk of rejected pull requests.
Asking and discussing first is generally always a good idea, since our road map is not very mature at this point.
